==> huaweicloudsdkimagesearch-3.0.83-py2.py3-none-any.whl: huaweicloudsdkimagesearch/v1/model/run_add_picture_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunAddPictureRequest:


    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_name': 'str',
        'body': 'AddPictureRequestReq'
    }

    attribute_map = {
        'instance_name': 'instance_name',
        'body': 'body'
    }

    def __init__(self, instance_name=None, body=None):
        """RunAddPictureRequest - a model defined in huaweicloud sdk"""
        
        

        self._instance_name = None
        self._body = None
        self.discriminator = None

        self.instance_name = instance_name
        if body is not None:
            self.body = body

    @property
    def instance_name(self):
        """Gets the instance_name of this RunAddPictureRequest.

        实例名称。

        :return: The instance_name of this RunAddPictureRequest.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this RunAddPictureRequest.

        实例名称。

        :param instance_name: The instance_name of this RunAddPictureRequest.
        :type: str
        """
        self._instance_name = instance_name

    @property
    def body(self):
        """Gets the body of this RunAddPictureRequest.


        :return: The body of this RunAddPictureRequest.
        :rtype: AddPictureRequestReq
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunAddPictureRequest.


        :param body: The body of this RunAddPictureRequest.
        :type: AddPictureRequestReq
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunAddPictureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkimagesearch-3.0.93-py2.py3-none-any.whl: huaweicloudsdkimagesearch/v1/model/run_add_picture_request.py <==
# coding: utf-8

import re
import six



from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class RunAddPictureRequest:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """

    sensitive_list = []

    openapi_types = {
        'instance_name': 'str',
        'body': 'AddPictureRequestReq'
    }

    attribute_map = {
        'instance_name': 'instance_name',
        'body': 'body'
    }

    def __init__(self, instance_name=None, body=None):
        """RunAddPictureRequest

        The model defined in huaweicloud sdk

        :param instance_name: 实例名称。
        :type instance_name: str
        :param body: Body of the RunAddPictureRequest
        :type body: :class:`huaweicloudsdkimagesearch.v1.AddPictureRequestReq`
        """
        
        

        self._instance_name = None
        self._body = None
        self.discriminator = None

        self.instance_name = instance_name
        if body is not None:
            self.body = body

    @property
    def instance_name(self):
        """Gets the instance_name of this RunAddPictureRequest.

        实例名称。

        :return: The instance_name of this RunAddPictureRequest.
        :rtype: str
        """
        return self._instance_name

    @instance_name.setter
    def instance_name(self, instance_name):
        """Sets the instance_name of this RunAddPictureRequest.

        实例名称。

        :param instance_name: The instance_name of this RunAddPictureRequest.
        :type instance_name: str
        """
        self._instance_name = instance_name

    @property
    def body(self):
        """Gets the body of this RunAddPictureRequest.


        :return: The body of this RunAddPictureRequest.
        :rtype: :class:`huaweicloudsdkimagesearch.v1.AddPictureRequestReq`
        """
        return self._body

    @body.setter
    def body(self, body):
        """Sets the body of this RunAddPictureRequest.


        :param body: The body of this RunAddPictureRequest.
        :type body: :class:`huaweicloudsdkimagesearch.v1.AddPictureRequestReq`
        """
        self._body = body

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RunAddPictureRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
